#

    	recipe

    		procedures:

    			nature_1 = food_USDA_nature.create (
    				USDA_examples.retrieve ("branded/walnuts_1882785.JSON")
    			)

    			import apoplast.shows.ingredient_scan_recipe.formulate as formulate_recipe
    			essential_nutrients_recipe = formulate_recipe.adroitly ([
    				[ nature_1, amount_1 ],
    				[ nature_2, amount_2 ]
    			])

    		status:
    			python3 insurance.py "shows/ingredient_scan_recipe/**/status_*.py"

    		priorities:
    			Calculate the selected unit of the
    			unit kinds first.

    			Then perhaps afterward, convert those
    			units into other units.

    				"mass + mass equivalents": {
    					"per recipe": {
    						"grams": {
    							"fraction string": "0"
    						}
    					}
    				},
    				"biological activity": {
    					"per recipe": {
    						"IU": {
    							"fraction string": "0"
    						}
    					}
    				},
    				"energy": {
    					"per recipe": {
    						"calories": {
    							"fraction string": "0"
    						}
    					}
    				}